420chan Python Library
======================
The Bibliotheca Anonoma's **complete Python Wrapper for the 420chan API.**
Uses requests, respects if-modified-since headers on updating threads.
Caches thread objects. Fun stuff.

An absolute must if you want to interface with or scrape from 4chan,
using a Python script.

`Hosted Documentation <http://py420chan.readthedocs.org/en/latest/index.html>`_

`Github Repository <https://github.com/bibanon/py420chan>`_

You can install this library `straight from
PyPi <https://pypi.python.org/pypi/py420chan>`_ with::

    pip install py420chan


**Getting Help**

If you want help, or you have some trouble using this library, our primary IRC channel
is `#bibanon on irc.rizon.net <http://qchat2.rizon.net/?channels=bibanon>`_. Simply head
in there and talk to dan or antonizoon. Otherwise, you can put a issue on our `Github
Issue Tracker <https://github.com/bibanon/BASC-py4chan>`_ and we'll respond as soon as
we can!

--------

Usage
-----

.. code:: python

    import py420chan
    nom = py420chan.Board('nom')
    thread = nom.get_thread(423491034)

    print(thread)

    for file in thread.file_objects():
        print(file.file_url)
        
    # In a while...
    print("I fetched", thread.update(), "new replies.")

Documentation
-------------

This library mostly extends the classes of `BASC-py4chan <https://github.com/bibanon/BASC-py4chan>`_, but has some differences. See the py8chan documentation for more info.

`py420chan Documentation <http://py420chan.readthedocs.org/en/latest/index.html>`_

Notice that some functions are not implemented in the 420chan API. These functions will `raise an AttributeError when used. <http://stackoverflow.com/a/23126260>`_

* omitted_posts - The lack of this feature forces us to ditch `expand()` and use `update()` instead.
* omitted_images - Because the `omitted` attributes are missing, the `repr` no longer reports them.
* filedeleted - The image will just 404 if it was deleted.
* spoiler
* images - No total of all images in the thread.
* bumplimit

License
-------

.. code:: text

                DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
                        Version 2, December 2004

     Copyright (C) 2004 Sam Hocevar <sam@hocevar.net>

     Everyone is permitted to copy and distribute verbatim or modified
     copies of this license document, and changing it is allowed as long
     as the name is changed.

                DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
       TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

      0. You just DO WHAT THE FUCK YOU WANT TO.
